.. _spkg_sagemath_database_jones_numfield:

=============================================================
sagemath_database_jones_numfield: Table of number fields
=============================================================


This pip-installable distribution ``passagemath-database-jones-numfield`` is a
distribution of a table of number fields with bounded ramification and degree
at most 6.


What is included
----------------

- Wheels on PyPI include the database_jones_numfield files


Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_database_jones_numfield`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.8.2.rc0

version_requirements.txt::

    passagemath-database-jones-numfield == 10.8.2rc0

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install passagemath-database-jones-numfield==10.8.2rc0

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sagemath_database_jones_numfield


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
